# TextFillMark


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**attrs** | [**Attrs**](Attrs.md) |  | [optional] 

## Example

```python
from src.client.generated.models.text_fill_mark import TextFillMark

# TODO update the JSON string below
json = "{}"
# create an instance of TextFillMark from a JSON string
text_fill_mark_instance = TextFillMark.from_json(json)
# print the JSON string representation of the object
print(TextFillMark.to_json())

# convert the object into a dict
text_fill_mark_dict = text_fill_mark_instance.to_dict()
# create an instance of TextFillMark from a dict
text_fill_mark_from_dict = TextFillMark.from_dict(text_fill_mark_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


